@@ -71,7 +71,7 @@ pub fn write_file<P: AsRef<Path>, S: AsRef<str>>(file_name: P, text: S) -> Resul
     };
 
     match file.write_all(text.as_bytes()) {
-        Ok(_) => {
+        Ok(()) => {
             log::trace!("File {file_name:?} written successfully");
         }
         Err(err) => {
@@ -136,7 +136,7 @@ pub fn display_command<T: AsRef<OsStr> + Debug, U: AsRef<OsStr> + Debug>(
     args: &[U],
 ) -> String {
     std::iter::once(cmd.as_ref())
-        .chain(args.iter().map(std::convert::AsRef::as_ref))
+        .chain(args.iter().map(AsRef::as_ref))
         .map(|i| i.to_string_lossy().into_owned())
         .collect::<Vec<String>>()
         .join(" ")
@@ -393,6 +393,10 @@ WebAssembly: unavailable
             stdout: String::from("Python 3.8.0\n"),
             stderr: String::default(),
         }),
+        "quarto --version" => Some(CommandOutput {
+            stdout: String::from("1.4.549\n"),
+            stderr: String::default(),
+        }),
         "R --version" => Some(CommandOutput {
             stdout: String::default(),
             stderr: String::from(
